import { Component, OnInit } from '@angular/core';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import { HttpClient } from '@angular/common/http';
import { ToastrService } from 'ngx-toastr';
import { PageEvent } from '@angular/material/paginator';

@Component({
  selector: 'app-pxe-boot-files',
  templateUrl: './pxe-boot-files.component.html',
  styleUrls: ['./pxe-boot-files.component.css']
})
export class PxeBootFilesComponent implements OnInit {
  baseUrl: string = import.meta.env.NG_APP_BASE_API_URL;

  availableOrganizationalUnits: any[] = [];
  selectedUnitChildren: any[] = [];
  dataSource: any[] = [];

  taskForm: FormGroup;

  loadingUnits: boolean = false;

  ogLiveOptions: string[] = ['Live Option 1', 'Live Option 2', 'Live Option 3'];

  globalOgLive: string | null = null;

  length: number = 100;
  itemsPerPage: number = 10;
  pageSizeOptions: number[] = [5, 10, 20, 40, 100];
  currentPage: number = 0;

  // Actualizar las columnas a mostrar
  displayedColumns: string[] = ['id', 'name', 'ogLive'];

  constructor(
    private fb: FormBuilder,
    private http: HttpClient,
    private toastService: ToastrService
  ) {
    this.taskForm = this.fb.group({
      organizationalUnit: ['', Validators.required],
      selectedChild: ['', Validators.required]
    });
  }

  ngOnInit(): void {
    this.fetchOrganizationalUnits();
  }

  fetchOrganizationalUnits(): void {
    this.loadingUnits = true;
    this.http.get<any>(`${this.baseUrl}/organizational-units?page=1&itemsPerPage=30`)
      .subscribe(
        response => {
          this.availableOrganizationalUnits = response['hydra:member'].filter((item: any) => item.type === 'organizational-unit');
          this.loadingUnits = false;
        },
        error => {
          this.toastService.error('Error al cargar las unidades organizativas');
          this.loadingUnits = false;
        }
      );
  }

  onOrganizationalUnitChange(): void {
    const selectedUnitId = this.taskForm.get('organizationalUnit')?.value;
    const selectedUnit = this.availableOrganizationalUnits.find(unit => unit['@id'] === selectedUnitId);
    if (selectedUnit && selectedUnit.children) {
      this.selectedUnitChildren = selectedUnit.children.filter((child: any) => child.type === 'classroom');
    } else {
      this.selectedUnitChildren = [];
    }
  }

  onChildChange(): void {
    const selectedChildId = this.taskForm.get('selectedChild')?.value;
    const selectedChild = this.selectedUnitChildren.find(child => child['@id'] === selectedChildId);
    if (selectedChild && selectedChild.clients) {
      this.dataSource = selectedChild.clients;
    } else {
      this.dataSource = [];
    }
  }

  applyToAll(): void {
    this.dataSource = this.dataSource.map(client => ({
      ...client,
      ogLive: this.globalOgLive || client.ogLive
    }));
  }

  onPageChange(event: PageEvent): void {
    this.currentPage = event.pageIndex;
    this.itemsPerPage = event.pageSize;
    this.search();
  }

  search(): void {
    // Logic for searching data if it comes from a paginated API would go here
  }

  syncOgCore(): void {
    this.http.post(`${this.baseUrl}/sync`, {}).subscribe(
      () => {
        this.toastService.success('Sincronización completada');
      },
      error => {
        this.toastService.error('Error al sincronizar');
      }
    );
  }
}
